@@ -1,35 +1,11 @@
-/*************************************************************************
- *
- * Copyright (c) 2010-2015 Kohei Yoshida
- *
- * Permission is hereby granted, free of charge, to any person
- * obtaining a copy of this software and associated documentation
- * files (the "Software"), to deal in the Software without
- * restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following
- * conditions:
- *
- * The above copyright notice and this permission notice shall be
- * included in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
- * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
- * OTHER DEALINGS IN THE SOFTWARE.
- *
- ************************************************************************/
+// SPDX-FileCopyrightText: 2010 - 2025 Kohei Yoshida
+//
+// SPDX-License-Identifier: MIT
 
-#ifndef INCLUDED_MDDS_SEGMENTTREE_HPP
-#define INCLUDED_MDDS_SEGMENTTREE_HPP
+#pragma once
 
-#include "mdds/node.hpp"
-#include "mdds/global.hpp"
+#include "./node.hpp"
+#include "./global.hpp"
 
 #include <vector>
 #include <deque>
@@ -38,6 +14,8 @@
 #include <unordered_map>
 #include <memory>
 #include <sstream>
+#include <type_traits>
+#include <utility>
 
 namespace mdds {
 
@@ -77,16 +55,22 @@ private:
         key_type end;
         value_type value;
 
-        segment_type();
+        static constexpr bool is_nothrow_less_v = noexcept(std::declval<key_type>() < std::declval<key_type>()) &&
+                                                  noexcept(std::declval<value_type>() < std::declval<value_type>());
+
+        static constexpr bool is_nothrow_equal_v = noexcept(std::declval<key_type>() == std::declval<key_type>()) &&
+                                                   noexcept(std::declval<value_type>() == std::declval<value_type>());
+
+        segment_type() = default;
         segment_type(key_type _start, key_type _end, value_type _value);
         segment_type(const segment_type&) = default;
         segment_type(segment_type&&) = default;
 
         segment_type& operator=(const segment_type& r) = default;
         segment_type& operator=(segment_type&& r) = default;
-        bool operator<(const segment_type& r) const;
-        bool operator==(const segment_type& r) const;
-        bool operator!=(const segment_type& r) const;
+        bool operator<(const segment_type& r) const noexcept(is_nothrow_less_v && is_nothrow_equal_v);
+        bool operator==(const segment_type& r) const noexcept(is_nothrow_equal_v);
+        bool operator!=(const segment_type& r) const noexcept(is_nothrow_equal_v);
     };
 
     using segment_store_type = std::deque<segment_type>;
@@ -266,6 +250,23 @@ private:
         search_results_base& m_results;
     };
 
+    static constexpr bool nothrow_default_constructible_v =
+        std::is_nothrow_default_constructible_v<std::vector<nonleaf_node>> &&
+        std::is_nothrow_default_constructible_v<segment_store_type> &&
+        std::is_nothrow_default_constructible_v<value_to_nodes_type> &&
+        std::is_nothrow_default_constructible_v<node_ptr>;
+
+    static constexpr bool nothrow_move_constructible_v =
+        std::is_nothrow_move_constructible_v<std::vector<nonleaf_node>> &&
+        std::is_nothrow_move_constructible_v<segment_store_type> &&
+        std::is_nothrow_move_constructible_v<value_to_nodes_type> && std::is_nothrow_move_constructible_v<node_ptr>;
+
+    static constexpr bool nothrow_swappable_v =
+        std::is_nothrow_swappable_v<std::vector<nonleaf_node>> && std::is_nothrow_swappable_v<segment_store_type> &&
+        std::is_nothrow_swappable_v<value_to_nodes_type> && std::is_nothrow_swappable_v<node_ptr>;
+
+    static constexpr bool nothrow_move_assignable_v = nothrow_move_constructible_v && nothrow_swappable_v;
+
 public:
     class search_results : public search_results_base
     {
@@ -338,13 +339,13 @@ public:
         }
     };
 
-    segment_tree();
+    segment_tree() noexcept(nothrow_default_constructible_v);
     segment_tree(const segment_tree& r);
-    segment_tree(segment_tree&& r);
+    segment_tree(segment_tree&& r) = default;
     ~segment_tree();
 
     segment_tree& operator=(const segment_tree& r);
-    segment_tree& operator=(segment_tree&& r);
+    segment_tree& operator=(segment_tree&& r) noexcept(nothrow_move_assignable_v);
 
     /**
      * Check equality with another instance.
@@ -442,7 +443,7 @@ public:
      *
      * @param r Another tree instance to swap the contents with.
      */
-    void swap(segment_tree& r) noexcept;
+    void swap(segment_tree& r) noexcept(nothrow_swappable_v);
 
     /**
      * Remove all segments data.
@@ -464,7 +465,11 @@ public:
      *
      * @return number of leaf nodes.
      */
-    size_type leaf_size() const;
+    size_type leaf_size() const
+        noexcept(noexcept(st::detail::count_leaf_nodes<size_type>(m_left_leaf.get(), m_right_leaf.get())))
+    {
+        return st::detail::count_leaf_nodes<size_type>(m_left_leaf.get(), m_right_leaf.get());
+    }
 
     /**
      * Create a string representation of the internal state of a tree.
@@ -560,5 +565,3 @@ private:
 } // namespace mdds
 
 #include "segment_tree_def.inl"
-
-#endif
